@@ -103,6 +103,11 @@ See L<Data::Stream::Bulk::DoneFlag>.
 
 Calls C<fetchall_arrayref> to get the next chunk of rows.
 
+=item all
+
+Calls C<fetchall_arrayref> to get the raminder of the data (without specifying
+C<max_rows).
+
 =back
 
 =cut
